---

slug: /create-regular-user
---

# Create a user

For enterprise users, when deploying seekdb, it is recommended to use a regular user. However, the user must have sudo privileges and be the owner of database-related directories. This topic describes how to create a regular user and set sudo privileges for the regular user.

1. Run the following commands to create the user group admin and create the user admin.

   ```shell
   useradd -U admin -d /home/admin -s /bin/bash
   chown -R admin:admin /home/admin
   ```

2. Run the following command to set a password for the admin account.

   ```shell
   passwd admin
   ```

3. Set sudo privileges for the admin account.

   Run the following command to open the `/etc/sudoers` file:

   ```shell
   vim /etc/sudoers
   ```

   Add the following content at the end of the `/etc/sudoers` file:

   ```shell
   ## Same thing without a password
   # %wheel        ALL=(ALL)       NOPASSWD: ALL
   admin       ALL=(ALL)       NOPASSWD: ALL
   ```
